diff src/minibuf.c @ 380:8626e4521993 r21-2-5

Import from CVS: tag r21-2-5
author cvs
date Mon, 13 Aug 2007 11:07:10 +0200
parents c5d627a313b1
children 74fd4e045ea6
line wrap: on
line diff
--- a/src/minibuf.c	Mon Aug 13 11:06:08 2007 +0200
+++ b/src/minibuf.c	Mon Aug 13 11:07:10 2007 +0200
@@ -289,14 +289,14 @@
 }
 
 
 /* #### Maybe we should allow ALIST to be a hashtable.  It is wrong
    for the use of obarrays to be better-rewarded than the use of
-   hashtables.  By better-rewarded I mean that you can pass an obarray
+   hash tables.  By better-rewarded I mean that you can pass an obarray
    to all of the completion functions, whereas you can't do anything
-   like that with a hashtable.
+   like that with a hash table.
 
    To do so, there should probably be a
-   map_obarray_or_alist_or_hashtable function which would be used by
+   map_obarray_or_alist_or_hash_table function which would be used by
    both Ftry_completion and Fall_completions.  But would the
    additional funcalls slow things down?  */
@@ -289,14 +289,14 @@
 
 
-/* #### Maybe we should allow ALIST to be a hashtable.  It is wrong
+/* #### Maybe we should allow ALIST to be a hash table.  It is wrong
    for the use of obarrays to be better-rewarded than the use of